database

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 16, 2026 License: BSD-2-Clause Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewConnectionPool

func NewConnectionPool(dsn string, config ...Configuration) (*sqlitex.Pool, error)

NewConnectionPool returns a database connection pool for the given DSN (see https://www.sqlite.org/uri.html).

Returns an error if the specified database file could not be opened.

Types

type Configuration

type Configuration struct {
	MaxConnections int
	Pragmas        map[string]string
	Flags          sqlite.OpenFlags
}

Jump to