Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewConnectionPool ¶
func NewConnectionPool(dsn string, config ...Configuration) (*sqlitex.Pool, error)
NewConnectionPool returns a database connection pool for the given DSN (see https://www.sqlite.org/uri.html).
Returns an error if the specified database file could not be opened.
Types ¶
Click to show internal directories.
Click to hide internal directories.